## This computes the logarithm of the flow equation

#!fields
# extrenal fields: xy0 where x=alpha, y=sigma
x:110,120,210,220
# internal fields: xy1 where x=alpha, y=sigma
i:111,121,211,221
# all are Fermions
f:110,120,210,220,111,121,211,221

&
#!groups
# different spins are independent
(111,211) (121,221)

&
#!preprocessor_variables

# psi's with internal fields
psiAU=(1/2)[f110]+[f111],
psiAD=(1/2)[f120]+[f121],
psiBU=(1/2)[f210]+[f211],
psiBD=(1/2)[f220]+[f221],

psiAU-=(1/2)[f-110]+[f-111],
psiAD-=(1/2)[f-120]+[f-121],
psiBU-=(1/2)[f-210]+[f-211],
psiBD-=(1/2)[f-220]+[f-221],

# operators with internal fields
O0=
<<$psiAU>*<$psiBU->>+
<<$psiBU>*<$psiAU->>+
<<$psiAD>*<$psiBD->>+
<<$psiBD>*<$psiAD->>,

O1=
<<$psiAU>*<$psiAU->*<$psiAD>*<$psiAD->>+
<<$psiBU>*<$psiBU->*<$psiBD>*<$psiBD->>,

O2=
<<$psiAU>*<$psiAD->*<$psiBD>*<$psiBU->>+
<<$psiBU>*<$psiBD->*<$psiAD>*<$psiAU->>+
<<$psiAD>*<$psiAU->*<$psiBU>*<$psiBD->>+
<<$psiBD>*<$psiBU->*<$psiAU>*<$psiAD->>,

O3=
<<$psiAU>*<$psiAU->*<$psiBU>*<$psiBU->>+
<<$psiAD>*<$psiAD->*<$psiBD>*<$psiBD->>,

O4=
<<$psiAU>*<$psiBU->*<$psiAD>*<$psiBD->>+
<<$psiBU>*<$psiAU->*<$psiBD>*<$psiAD->>,

O5=
<<$psiAU>*<$psiAU->*<$psiAD>*<$psiBU->*<$psiBU>*<$psiBD->>+
<<$psiAD>*<$psiAD->*<$psiAU>*<$psiBD->*<$psiBD>*<$psiBU->>+
<<$psiBU>*<$psiBU->*<$psiBD>*<$psiAU->*<$psiAU>*<$psiAD->>+
<<$psiBD>*<$psiBD->*<$psiBU>*<$psiAD->*<$psiAD>*<$psiAU->>,

O6=<<$psiAU>*<$psiAU->*<$psiAD>*<$psiAD->*<$psiBU>*<$psiBU->*<$psiBD>*<$psiBD->>,


# psi's without internal fields
phiAU=[f110],
phiAD=[f120],
phiBU=[f210],
phiBD=[f220],

phiAU-=[f-110],
phiAD-=[f-120],
phiBU-=[f-210],
phiBD-=[f-220],

# operators without internal fields
E0=
<<$phiAU>*<$phiBU->>+
<<$phiBU>*<$phiAU->>+
<<$phiAD>*<$phiBD->>+
<<$phiBD>*<$phiAD->>,

E1=
<<$phiAU>*<$phiAU->*<$phiAD>*<$phiAD->>+
<<$phiBU>*<$phiBU->*<$phiBD>*<$phiBD->>,

E2=
<<$phiAU>*<$phiAD->*<$phiBD>*<$phiBU->>+
<<$phiBU>*<$phiBD->*<$phiAD>*<$phiAU->>+
<<$phiAD>*<$phiAU->*<$phiBU>*<$phiBD->>+
<<$phiBD>*<$phiBU->*<$phiAU>*<$phiAD->>,

E3=
<<$phiAU>*<$phiAU->*<$phiBU>*<$phiBU->>+
<<$phiAD>*<$phiAD->*<$phiBD>*<$phiBD->>,

E4=
<<$phiAU>*<$phiBU->*<$phiAD>*<$phiBD->>+
<<$phiBU>*<$phiAU->*<$phiBD>*<$phiAD->>,

E5=
<<$phiAU>*<$phiAU->*<$phiAD>*<$phiBU->*<$phiBU>*<$phiBD->>+
<<$phiAD>*<$phiAD->*<$phiAU>*<$phiBD->*<$phiBD>*<$phiBU->>+
<<$phiBU>*<$phiBU->*<$phiBD>*<$phiAU->*<$phiAU>*<$phiAD->>+
<<$phiBD>*<$phiBD->*<$phiBU>*<$phiAD->*<$phiAD>*<$phiAU->>,

E6=<<$phiAU>*<$phiAU->*<$phiAD>*<$phiAD->*<$phiBU>*<$phiBU->*<$phiBD>*<$phiBD->>

&
#!propagator
111;211: 1 ,121;221: 1 ,
211;111: 1 ,221;121: 1

&
#!input_polynomial
<%exp<
  <<[l0]>*<$O0>>+
  <<[l1]>*<$O1>>+
  <<[l2]>*<$O2>>+
  <<[l3]>*<$O3>>+
  <<[l4]>*<$O4>>+
  <<[l5]>*<$O5>>+
  <<[l6]>*<$O6>>
>>

&
#!postprocess_flow_equation
<<8>*<%log_1<$FLOW>>>

&
#!id_table
0: <$E0>,
1: <$E1>,
2: <$E2>,
3: <$E3>,
4: <$E4>,
5: <$E5>,
6: <$E6>

&
#!labels

0:"O0" ,
1:"O1" ,
2:"O2" ,
3:"O3" ,
4:"O4" ,
5:"O5" ,
6:"O6"
